@@ -10,7 +10,7 @@ use File::Spec::Functions qw(catfile abs2rel);
 use Serge::Util qw(subst_macros);
 use version;
 
-our $VERSION = qv('0.901.2');
+our $VERSION = qv('0.902.0');
 
 sub name {
     return 'Lokalise translation software (https://lokalise.co/) synchronization plugin';
@@ -25,9 +25,9 @@ sub init {
 
     $self->merge_schema({
         config_file    => 'STRING',
+        root_directory         => 'STRING',
         resource_directory => 'STRING',
         languages      => 'ARRAY',
-        file_mask      => 'STRING',
         file_format    => 'STRING'
     });
 }
@@ -40,16 +40,16 @@ sub validate_data {
     $self->{data}->{config_file} = subst_macros($self->{data}->{config_file});
     $self->{data}->{cleanup_mode} = subst_macros($self->{data}->{cleanup_mode});
     $self->{data}->{languages} = subst_macros($self->{data}->{languages});
-    $self->{data}->{file_mask} = subst_macros($self->{data}->{file_mask});
     $self->{data}->{file_format} = subst_macros($self->{data}->{file_format});
 
+    $self->{data}->{resource_directory} = subst_macros($self->{data}->{resource_directory});
+
     die "'config_file' not defined" unless defined $self->{data}->{config_file};
     die "'config_file', which is set to '$self->{data}->{config_file}', does not point to a valid file.\n" unless -f $self->{data}->{config_file};
 
     die "'resource_directory' not defined" unless defined $self->{data}->{resource_directory};
     die "'resource_directory', which is set to '$self->{data}->{resource_directory}', does not point to a valid folder.\n" unless -d $self->{data}->{resource_directory};
     
-    die "'file_mask' not defined" unless defined $self->{data}->{file_mask};
     die "'file_format' not defined" unless defined $self->{data}->{file_format};
 
     if (!defined $self->{data}->{languages} or scalar(@{$self->{data}->{languages}}) == 0) {
@@ -62,7 +62,7 @@ sub run_lokalise_cli {
 
     my $command = ' --config '.$self->{data}->{config_file}.' '.$action;
 
-    $command = 'lokalise '.$command;
+    $command = 'lokalise2 '.$command;
     print "Running '$command'...\n";
     return $self->run_cmd($command);
 }
@@ -78,16 +78,15 @@ sub get_lokalise_lang {
 sub pull_ts {
     my ($self, $langs) = @_;
 
-    my $action = 'export --type '.$self->{data}->{file_format};
-    $action .= ' --use_original 1';
-    $action .= ' --unzip_to '.$self->{data}->{resource_directory};
+    my $action = 'file download --format '.$self->{data}->{file_format};
+    $action .= ' --unzip-to '.$self->{data}->{resource_directory};
 
     if ($langs) {
         my @lokalise_langs = map {$self->get_lokalise_lang($_)} @$langs;
 
         my $langs_as_string = join(',', @lokalise_langs);
 
-        $action .= ' --langs '.$langs_as_string;
+        $action .= ' --filter-langs '.$langs_as_string;
     }
 
     return $self->run_lokalise_cli($action);
@@ -99,18 +98,20 @@ sub push_ts {
     my $langs_to_push = $self->get_langs($langs);
 
     foreach my $lang (@$langs_to_push) {
-        my $action = 'import';
+        my $action = 'file upload';
 
-        my $directory = catfile($self->{data}->{resource_directory}, $lang);
-        my $file_mask = catfile($directory, $self->{data}->{file_mask});
+        my $lang_files_path = catfile($self->{data}->{resource_directory}, $lang);
+        my @files = $self->find_lang_files($lang_files_path);
 
-        $action .= ' --file '.$file_mask.' --lang_iso '.$self->get_lokalise_lang($lang);
-        $action .= ' --replace 1 --fill_empty 0 --distinguish 1';
+        foreach my $file (@files) {
+            my $full_file_path = catfile($lang_files_path, $file);
+            $action .= ' --file ' . $full_file_path . ' --lang-iso ' . $self->get_lokalise_lang($lang);
 
-        my $cli_return = $self->run_lokalise_cli($action, ());
+            my $cli_return = $self->run_lokalise_cli($action, ());
 
-        if ($cli_return != 0) {
-            return $cli_return;
+            if ($cli_return != 0) {
+                return $cli_return;
+            }
         }
     }
 
@@ -127,4 +128,16 @@ sub get_langs {
     return $langs;
 }
 
+sub find_lang_files {
+    my ($self, $directory) = @_;
+
+    my @files = ();
+
+    find(sub {
+        push @files, abs2rel($File::Find::name, $directory) if(-f $_);
+    }, $directory);
+
+    return @files;
+}
+
 1;
\ No newline at end of file
